@@ -1,7 +1,7 @@
 package Validator::Custom;
 use Object::Simple -base;
 use 5.008001;
-our $VERSION = '1.00_03';
+our $VERSION = '1.00_04';
 
 use Carp 'croak';
 use Validator::Custom::Validation;
@@ -782,42 +782,44 @@ Validator::Custom - HTML form Validation, simple and good flexibility
   # Input data
   my $id = 1;
   my $name = 'Ken Suzuki';
-  my $age = ' 19 ';
-  my $favorite = ['apple', 'orange'];
+  my $price = ' 19.23 ';
+  my $favorite = ['001', '002'];
   
   # Create validation object
   my $validation = $vc->validation;
   
-  # Check id
+  # Check if id is integer
   if (!$vc->check($id, 'int')) {
     # Add failed message
     $validation->add_failed(id => 'id must be integer');
   }
   
-  # Check name
+  # Check if name has length
   if (!(length $name)) {
     $validation->add_failed(name => 'name must have length');
   }
+  # Check if name's length is less than 30
   elsif (!(length $name < 30)) {
     $validation->add_failed(name => 'name is too long');
   }
   
-  # Filter age
-  $age = $vc->filter($age, 'trim');
+  # Filter price to remove left-rigth space
+  $price = $vc->filter($price, 'trim');
 
-  # Check age
-  if (!$vc->check($age, 'int')) {
+  # Check price is number and the digits of the decimal part is two or less than two
+  if (!$vc->check($price, 'number', {decimal_part_max => 2})) {
     # Set default value if validation fail
-    $age = 20;
+    $price = 20.25;
+  }
   
-  # Filter each value of favorite
+  # Filter each value of favorite using "trim" filtering function
   $favorite = $vc->filter_each($favorite, 'trim');
   
-  # Check each value of favorite
-  if (@$favorite == 0) {
+  # Check if favorite has at least one values
+  if (@$favorite > 0) {
     $validation->add_failed(favorite => 'favorite must be selected more than one');
   }
-  elsif (!($vc->check_each($favorite, 'in',  ['apple', 'ornge', 'peach']))) {
+  elsif (!($vc->check_each($favorite, 'in',  ['001', '002', 'peach']))) {
     $validation->add_failed(favorite => 'favorite is invalid');
   }
   
@@ -841,7 +843,7 @@ Validator::Custom - HTML form Validation, simple and good flexibility
     # Get all failed parameter messages
     my $messages = $validation->messages;
     
-    # Get all failed parameter names and the messages as hash
+    # Get all failed parameter names and the messages as hash reference
     my $messages_h = $validation->messages_to_hash;
   }
   
@@ -856,16 +858,16 @@ The features are the following ones.
 
 =item *
 
-Sevral check functions are available by default, C<ascii>,
-C<int>, C<decimal>, C<uint> C<in>.
+Sevral checking functions are available by default, C<ascii_graphic>,
+C<int>, C<number>, C<in>.
 
 =item *
 
-Several filter functions are available by default, such as C<trim>.
+Several filtering functions are available by default, such as C<trim>, C<remove_blank>.
 
 =item *
 
-You can add your check and filter function.
+You can add your own checking and filtering function.
 
 =item *
 
@@ -877,60 +879,63 @@ and the messages keeping the order of validation.
 
 =head1 GUIDE
 
-=head2 1. Basic
+=head2 1. Basic usage
 
-B<1. Create a new Validator::Custom object>
+=head3 1. Create a new Validator::Custom object
 
-At first, create L<Validator::Custom> object.
+At first, create L<Validator::Custom> object using C<new> method.
 
   use Validator::Custom;
   my $vc = Validator::Custom->new;
 
-B<2. Prepare input data for validation>
+=head3 2. Prepare input data for validation
 
 Next, prepare input data.
 
   my $id = 1;
   my $name = 'Ken Suzuki';
-  my $age = ' 19 ';
-  my $favorite = ['apple', 'orange'];
+  my $price = ' 19.23 ';
+  my $favorite = ['001', '002'];
 
-B<3. Create validation object>
+=head3 3. Create a new validation object
 
-Next, create validation object.
+Next, create a new validation object using C<validation> method.
 
   my $validation = $vc->validation;
 
 This is L<Validator::Custom::Validation> object
 to store failed parameter names and the messages.
 
-B<4. Validate input data>
+=head3 4. Validate input data
 
-  # Check id
+  # Check if id is integer
   if (!$vc->check($id, 'int')) {
     # Add failed message
     $validation->add_failed(id => 'id must be integer');
   }
 
-You can use C<int> check function to check the value is integer.
+You can use C<int> checking function to check the value is integer.
+C<int> checking function is default one.
+Any checking function is available through C<check> method.
+
 If the check fail, you can add failed parameter name and that message
 using C<add_failed> method.
   
-  # Filter age
-  $age = $vc->filter($age, 'trim');
+  # Filter price to remove left-rigth space
+  $price = $vc->filter($price, 'trim');
 
 You can use C<trim> filter function to trim left-rigth spaces.
   
-  # Filter each value of favorite
+  # Filter each value of favorite using "trim" filtering function
   $favorite = $vc->filter_each($favorite, 'trim');
 
 You can use C<filter_each> method to filter each value of favorite.
   
-  # Check each value of favorite
-  if (@$favorite == 0) {
+  # Check if favorite has at least one values
+  if (@$favorite > 0) {
     $validation->add_failed(favorite => 'favorite must be selected more than one');
   }
-  elsif (!($vc->check_each($favorite, 'in',  ['apple', 'ornge', 'peach']))) {
+  elsif (!($vc->check_each($favorite, 'in',  ['001', '002', 'peach']))) {
     $validation->add_failed(favorite => 'favorite is invalid');
   }
 
@@ -939,7 +944,7 @@ You can use C<check_each> method to check each value of favorite.
 If you see default checks and filter,
 see L<Validator::Custom/"CHECKING FUNCTIONS"> and L<Validator::Custom/"FILTERING FUNCTIONS">.
 
-B<5. Manipulate validation object>
+=head2 2. Manipulate validation object
 
 If you check all input data is valid, use C<is_valid> method.
   
@@ -980,7 +985,9 @@ You can get all failed names and the messages as hash.
 
 See also L<Validator::Custom::Validation>.
 
-=head2 2. Add checking function
+=head2 Advanced tequnique
+
+=head3 1. Add checking function
 
 You can add your check function by C<add_check> method if you need.
 
@@ -1003,7 +1010,7 @@ the argument as third argument.
 
 You must return the result of validation, true or false value.
 
-=head3 Add filtering function
+=head3 2. Add filtering function
 
 You can add your filtering function by C<add_filter> method if you need.
 
@@ -1029,22 +1036,6 @@ You must return the result of filtering.
 L<Validator::Custom> have the following default checking functions.
 You can call any checking function by C<check> method.
 
-=head2 ascii_graphic
-  
-  my $is_valid = $vc->check($value, 'ascii');
-  
-Ascii graphic characters(hex 21-7e). Generally, you can use C<ascii_graphic> function
-for checking the characters of a password.
-
-Valid example:
-
-  "Ken!@-"
-
-Invalid example:
-  
-  "aa aa"
-  "\taaa"
-
 =head2 int
 
   my $value = 19;
@@ -1066,24 +1057,6 @@ If you need to check the range of value, you can write the following way.
 
   my $is_valid =  $vc->check($value, 'int') && $value > 0;
 
-=head2 in
-  
-  my $value = '001';
-  my $is_valid = $vc->check($value, 'in', ['001', '002', '003']);
-
-Check if the value is one of the values of the array.
-
-Valid example:
-
-  '001'
-  '002'
-  '003'
-
-Invalid example:
-
-  '004'
-  '005'
-
 =head2 number
   
   my $is_valid = $vc->check($value, 'number');
@@ -1120,6 +1093,40 @@ Invalid example:
   '123.4567'
   '-100.7891'
 
+=head2 ascii_graphic
+  
+  my $is_valid = $vc->check($value, 'ascii');
+  
+Ascii graphic characters(hex 21-7e). Generally, you can use C<ascii_graphic> function
+for checking the characters of a password.
+
+Valid example:
+
+  "Ken!@-"
+
+Invalid example:
+  
+  "aa aa"
+  "\taaa"
+
+=head2 in
+  
+  my $value = '001';
+  my $is_valid = $vc->check($value, 'in', ['001', '002', '003']);
+
+Check if the value is one of the values of the array.
+
+Valid example:
+
+  '001'
+  '002'
+  '003'
+
+Invalid example:
+
+  '004'
+  '005'
+
 =head1 FILTERING FUNCTIONS
 
 L<Validator::Custom> have the following default filtering functions.
@@ -1256,14 +1263,14 @@ Password checking.
 
 Check box, selected at least 1.
 
-  my $favorite = ['apple', 'orange'];
+  my $favorite = ['001', '002'];
 
   my $validation = $vc->validation;
   
   if (@$favorite == 0) {
     $validation->add_failed(favorite => 'favorite must be selected at least 1');
   }
-  elsif (!$vc->check($favorite, 'in', ['apple', 'orange', 'melon'])) {
+  elsif (!$vc->check($favorite, 'in', ['001', '002', '003'])) {
     $validation->add_failed(favorite => 'favorite have invalid value');
   }
   
